MiniMapWindow = class( Turbine.UI.Window );

function MiniMapWindow:Constructor(parent)
	Turbine.UI.Window.Constructor( self );
	
	self:SetSize( 304, 235 );
	self:SetVisible(false);
	self:SetText( "Minimap :)" );
	
	if(Preferences.minimap_x==nil or Preferences.minimap_y==nil) then
		Preferences.minimap_x = Preferences.main_x;
		Preferences.minimap_y = Preferences.main_y;
	end
	
	self:SetPosition(Preferences.minimap_x, Preferences.minimap_y);
	
	self.parent = parent;
	
	self.PositionChanged = function(sender, args)
		Preferences.minimap_x, Preferences.minimap_y = self:GetPosition();
		SavePreferences();
	end	
	
	-- Hide UI when F12 is pressed, code copied from Chiran sources
	local hideUI = false;
	local wasVisible;
	self:SetWantsKeyEvents(true);
	self.KeyDown = function(sender, args)
		if (args.Action == 268435635) then
			if not hideUI then
				hideUI = true;
				if self:IsVisible() then
					wasVisible = true;
					self:SetVisible(false);					
				else
					wasVisible = false;
				end
				-- settingsWindow:SetVisible(false);
				-- toggleWindow:SetVisible(false);
			else
				hideUI = false;
				if wasVisible then
					self:SetVisible(true);
					-- settingsWindow:SetVisible(false);					
				end
				-- if (Settings.ToggleVisible == "yes") then
					-- toggleWindow:SetVisible(true);
				-- end
			end
		end
	end
	self.map = MiniMapViewer(self, false);
	self.map:SetPosition( 0, 32 );
	self:SetSize(self.map:GetWidth(), self.map:GetHeight()+32);

	local titleLeft = Turbine.UI.Label();
	titleLeft:SetParent( self );
	titleLeft:SetPosition(0, 0);
	titleLeft:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	titleLeft:SetSize(35, 42);
	titleLeft:SetBackground("WalmPlugins/WarbandsSlayer/resources/box/base_box_titlebar_left.tga");
	local titleRight = Turbine.UI.Label();
	titleRight:SetParent( self );
	titleRight:SetPosition(self:GetWidth()-35, 0);
	titleRight:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	titleRight:SetSize(35, 42);
	titleRight:SetBackground("WalmPlugins/WarbandsSlayer/resources/box/base_box_titlebar_right.tga");	
	local titleCenter = Turbine.UI.Label();
	titleCenter:SetParent( self );
	titleCenter:SetPosition(35, 0);
	titleCenter:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	titleCenter:SetSize(self:GetWidth()-35-35, 42);
	titleCenter:SetBackground("WalmPlugins/WarbandsSlayer/resources/box/base_box_titlebar_center.tga");
	self.nameLabel = Turbine.UI.Label();
	self.nameLabel:SetParent( self );
	self.nameLabel:SetSize(self:GetWidth()-35-35, 24);
	self.nameLabel:SetPosition(35, 12);
	self.nameLabel:SetFont( Turbine.UI.Lotro.Font.TrajanPro13 );		
	self.nameLabel:SetForeColor( Turbine.UI.Color(0.9, 0.9, 0.2) );
	self.nameLabel:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter );
	self.nameLabel:SetMouseVisible( false );
	
	local closeBtn = Turbine.UI.Label();
	closeBtn:SetParent( self );
	closeBtn:SetBackground( "WalmPlugins/WarbandsSlayer/resources/bubble/close.jpg" );
	closeBtn:SetPosition( self:GetWidth()-23, 37);
	closeBtn:SetSize(16, 16);
	closeBtn.MouseClick = function( sender, args )
		self:Close();
		if(parent~=nil) then
			--self.parent:UpdateMap(self.warband);
			parent.treeView:SelectedNodeChanged();
			parent:SetVisible(true);
		end
	end	
	titleCenter.MouseDown = function( sender, args )
		if(args.Button == Turbine.UI.MouseButton.Left) then
			sender.dragStartX = args.X;
			sender.dragStartY = args.Y;
			sender.dragging = true;
			sender.dragged = false;
		end
	end
	titleCenter.MouseUp = function( sender, args )
		if (args.Button == Turbine.UI.MouseButton.Left) then			
			if (sender.dragging) then
				Preferences.minimap_x, Preferences.minimap_y = self:GetPosition();
				SavePreferences();			
				sender.dragging = false;
			end
		end
	end
	titleCenter.MouseMove = function(sender,args)
		if ( sender.dragging ) then
			local left, top = self:GetPosition();
			self:SetPosition( left + ( args.X - sender.dragStartX ), top + args.Y - sender.dragStartY );
			sender.dragged = true;
			if (self:GetLeft() > Turbine.UI.Display.GetWidth() - 35) then
				self:SetLeft(Turbine.UI.Display.GetWidth() - 35);				
			end
			if (self:GetLeft() < 0) then
				self:SetLeft(0);				
			end			
			if (self:GetTop() > Turbine.UI.Display.GetHeight() - 35) then
				self:SetTop(Turbine.UI.Display.GetHeight() - 35);				
			end
			if (self:GetTop() < 0) then
				self:SetTop(0);				
			end			
		end
	end	
	titleLeft.MouseDown = titleCenter.MouseDown;
	titleRight.MouseDown = titleCenter.MouseDown;
	titleLeft.MouseUp = titleCenter.MouseUp;
	titleRight.MouseUp = titleCenter.MouseUp;
	titleLeft.MouseMove = titleCenter.MouseMove;
	titleRight.MouseMove = titleCenter.MouseMove;
end

function MiniMapWindow:ShowAllMarks(warband, pos)
	self.map.allMarks.wData = warband;
	self.map.allMarks.l = pos;
	self.map.allMarks:SetPushed(true);
	self.map.allMarks:Toggled(self, true);
	--local result = self.map:ShowAllMarks(warband, pos, area, true);
	-- if result then
	--self.nameLabel:SetText( area.name );
	-- end
	-- return result;
end

function MiniMapWindow:UpdatePlayerPosition(x, y)
	self.map:UpdatePlayerPosition(x, y);
end

function MiniMapWindow:UpdateMap(warband, pos)
	local result = self.map:UpdateMap(warband, pos, nil, true);
	-- if result then
		-- self.nameLabel:SetText( warband.name );
	-- end
	return result;
end

function MiniMapWindow:OnPOIUpdated(wad, poi)
	if(self.map ~= nil) then self.map:OnPOIUpdated(wad, poi); end
end

function MiniMapWindow:IsRunning()
	return ( self ~= nil );
end

function MiniMapWindow:Stop()
	self = nil;
end