import "WalmPlugins.WarbandsSlayer.src.LerpValue";
import "WalmPlugins.WarbandsSlayer.src.BubblePopup";

QuickLauncher = class( Turbine.UI.Window );

function QuickLauncher:Constructor(dialog)
	Turbine.UI.Window.Constructor( self );
	
	--self.defaultOpacity = 0.6;
	local width, height = Turbine.UI.Display.GetSize();
	self:SetSize(42, 50);
	self:SetPosition(Preferences.quicklaunch_x, Preferences.quicklaunch_y);
	self:SetOpacity(Preferences.defaultOpacity / 100);
	
	self.background = Turbine.UI.Label();
	self.background:SetParent( self );
	self.background:SetBackground( "WalmPlugins/WarbandsSlayer/resources/quicklauncher/quicklauncher.tga" );
	self.background:SetPosition( (self:GetWidth()-32)/2, 0 );
	self.background:SetSize(32, 32);
	self.background:SetMouseVisible( false );
	self.background:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );	

	self.cell = Turbine.UI.Label();
	self.cell:SetParent( self );
	self.cell:SetBackground( "WalmPlugins/WarbandsSlayer/resources/quicklauncher/quicklauncher_cell.tga" );
	self.cell:SetSize(38, 15);
	self.cell:SetPosition( self:GetWidth()/2-self.cell:GetWidth()/2, self:GetHeight()-self.cell:GetHeight()-4);
	self.cell:SetMouseVisible( false );
	self.cell:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );	


	self.qsBubble = Turbine.UI.Lotro.Quickslot();
	self.qsBubble:SetParent(self);
	self.qsBubble:SetSize(16,16);
	self.qsBubble:SetPosition(34,0);
	self.qsBubble:SetBackColor( Turbine.UI.Color( 0.6, 0, 0, 0 ) );
	self.qsBubble:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, ""));	
	self.qsBubble:SetAllowDrop(false);
	self.qsBubble:SetEnabled(false);
	
	local c= Turbine.UI.Control();
	c:SetParent(self);
	c:SetSize(self.qsBubble:GetSize());
	c:SetPosition(self.qsBubble:GetLeft(),self.qsBubble:GetTop());
	c:SetMouseVisible(false);
	c:SetZOrder(10000);
	c:SetBackColor(Turbine.UI.Color( .7, .7, .7 ));
	self.qsLbl = c;
	
	c= Turbine.UI.Label()
	c:SetParent(self.qsLbl);
	c:SetPosition(1,1);
	c:SetSize(self.qsBubble:GetWidth()-2,self.qsBubble:GetHeight()-2);
	c:SetMouseVisible(false);
	c:SetZOrder(10001);
	c:SetBackground( "WalmPlugins/WarbandsSlayer/resources/quicklauncher/bubble.tga" );
	
	self.qsBubble:SetVisible(false);
	self.qsLbl:SetVisible(false);
	
	self.counter = Turbine.UI.Label();
	self.counter:SetParent( self.cell );
	self.counter:SetText( "0/30" );
	self.counter:SetPosition(0, 0);
	self.counter:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter );
	self.counter:SetFont(Turbine.UI.Lotro.Font.Verdana10); 
	self.counter:SetSize(self.cell:GetSize());
	self.counter:SetMouseVisible( false );
	
	local contextMenu = Turbine.UI.ContextMenu();
	menuItems = contextMenu:GetItems();
	local openMenuItem = Turbine.UI.MenuItem( TRAD("Ouvrir la fenêtre principale", "Open main window") );
	local configMenuItem = Turbine.UI.MenuItem( TRAD("Ouvrir le panneau de configuration", "Open configuration window") );
    menuItems:Add( openMenuItem );
    menuItems:Add( configMenuItem );
	openMenuItem.Click = function(sender, args)
		dialog:SetVisible( not dialog:IsVisible() );
	end
	configMenuItem.Click = function(sender, args)
		local configDialog = GetConfigurationDialogInstance();
		configDialog:SetVisible(true);
	end
	
	self.MouseEnter = function(sender,args)
		self:SetOpacity(1.0);
	end
	self.MouseLeave = function(sender,args)
		self:SetOpacity(Preferences.defaultOpacity / 100);
	end		
	self.MouseDown = function( sender, args )
		if(args.Button == Turbine.UI.MouseButton.Left and Preferences.canMoveQuickLauncher) then
			sender.dragStartX = args.X;
			sender.dragStartY = args.Y;
			sender.dragging = true;
			sender.dragged = false;
		end
	end
	self.MouseUp = function( sender, args )
		if (args.Button == Turbine.UI.MouseButton.Left) then			
			if (sender.dragging) then
				sender.dragging = false;
			end
			if not sender.dragged then
				dialog:SetVisible( not dialog:IsVisible() );
			end
			Preferences.quicklaunch_x, Preferences.quicklaunch_y = self:GetPosition();
			SavePreferences();
			if(Preferences.OnUpdate ~= nil) then
				Preferences.OnUpdate();
			end
		elseif (args.Button == Turbine.UI.MouseButton.Right) then	
			contextMenu:ShowMenu();
		end
	end
	self.MouseMove = function(sender,args)
		if ( sender.dragging ) then
			local left, top = self:GetPosition();
			self:SetPosition( left + ( args.X - sender.dragStartX ), top + args.Y - sender.dragStartY );
			sender.dragged = true;
			if (self:GetLeft() > Turbine.UI.Display.GetWidth() - 35) then
				self:SetLeft(Turbine.UI.Display.GetWidth() - 35);				
			end
			if (self:GetLeft() < 0) then
				self:SetLeft(0);				
			end			
			if (self:GetTop() > Turbine.UI.Display.GetHeight() - 35) then
				self:SetTop(Turbine.UI.Display.GetHeight() - 35);				
			end
			if (self:GetTop() < 0) then
				self:SetTop(0);				
			end			
		end
	end
	
	self.lastUpdate = 0;
	self.blinker = LerpValue();
	self.blinker:SetRate(60);
	
	self:ApplyPreferences();
	
	local hideUI = false;
	local wasVisible;
	self:SetWantsKeyEvents(true);
	self.KeyDown = function(sender, args)
		if (args.Action == 268435635) then
			if not hideUI then
				hideUI = true;
				if self:IsVisible() then
					wasVisible = true;
					self:SetVisible(false);					
				else
					wasVisible = false;
				end
			else
				hideUI = false;
				if wasVisible then
					self:SetVisible(true);				
				end
			end
		end
	end
	self:InitTargetLogger();
end

function QuickLauncher:NotifyUpdate(doneCount, total, justkilled, typeId)
	if(typeId==2) then
		self.background:SetBackground( "WalmPlugins/WarbandsSlayer/resources/quicklauncher/quicklauncher2.tga" );
	elseif(typeId==3) then
		self.background:SetBackground( "WalmPlugins/WarbandsSlayer/resources/quicklauncher/quicklauncher3.tga" );
	elseif(typeId==4) then
		self.background:SetBackground( "WalmPlugins/WarbandsSlayer/resources/quicklauncher/quicklauncher4.tga" );
	elseif(typeId==5) then
		self.background:SetBackground( "WalmPlugins/WarbandsSlayer/resources/quicklauncher/quicklauncher5.tga" );
	else
		self.background:SetBackground( "WalmPlugins/WarbandsSlayer/resources/quicklauncher/quicklauncher.tga" );
	end
	local str = (doneCount or 0).."/"..(total or 0);
	if(str==self.counter:GetText()) then return; end
	self.counter:SetText( str );
	if(justkilled==nil or justkilled==false) then
		self.blinker.iteration = 4;
		self.blinker:SetTarget(Preferences.defaultOpacity);
		self.blinker:SetValue(0);
	else
		self.blinker.iteration = 5;
		self.blinker:SetTarget(0);
		self.blinker:SetValue(self:GetOpacity()*100);	
	end
	self:SetWantsUpdates( true );
	
end

function QuickLauncher:Update( args )
	local delta = 0;
	local currentTime = Turbine.Engine.GetGameTime();

	if ( self.lastUpdate > 0 ) then
		delta = currentTime - self.lastUpdate;
	end

	self.lastUpdate = currentTime;
	
	self.blinker:Update( delta );
	self:SetOpacity(self.blinker:GetValue()/100);
	
	if (not self.blinker:NeedsUpdate()) then
		if(self.blinker.iteration > 0) then
			if(self.blinker.iteration%2==0) then
				self.blinker:SetTarget(0);
				self.blinker:SetValue(Preferences.defaultOpacity);
			else
				self.blinker:SetTarget(Preferences.defaultOpacity);
				self.blinker:SetValue(0);
			end
			self.blinker.iteration = self.blinker.iteration - 1;
		else
			self:SetWantsUpdates( false );
			self.lastUpdate = 0;
		end
	end	
end

function QuickLauncher:ApplyPreferences()
	self:SetPosition(Preferences.quicklaunch_x, Preferences.quicklaunch_y);
	self:SetOpacity(Preferences.defaultOpacity / 100);
end

function QuickLauncher:GetName()
	return "QuickLauncher";
end

function QuickLauncher:IsRunning()
	return ( self ~= nil );
end

function QuickLauncher:Start()
	if ( self ~= nil ) then
		self:SetVisible( true );
		return;
	end	
end

function QuickLauncher:Stop()
	self:SetVisible(false);
	self = nil;
end

function QuickLauncher:InitTargetLogger()
	if(Turbine.Gameplay.LocalPlayer.targetListerners == nil) then
		Turbine.Gameplay.LocalPlayer.targetListerners = {};
		local player=Turbine.Gameplay.LocalPlayer.GetInstance();
		player.TargetChanged = function (sender, args)
			for i, j in pairs(Turbine.Gameplay.LocalPlayer.targetListerners) do
				j:TargetChanged(sender, args);
			end
		end
	end
	if (Turbine.Gameplay.LocalPlayer.targetListerners ~= nil) then
		for i, j in pairs(Turbine.Gameplay.LocalPlayer.targetListerners) do
			if(j==self) then return; end
		end
		table.insert(Turbine.Gameplay.LocalPlayer.targetListerners, self);
	end	
end

function QuickLauncher:TargetChanged(sender, args)
	local player=Turbine.Gameplay.LocalPlayer.GetInstance();
	local target=player:GetTarget();
	if target~=nil then
		local targetname = target:GetName();
		wb = GetWarbandByQuestName(targetname);
		if(wb==nil and target~=nil) then
			local wbName2 = StringCleaner(targetname);
			wb = GetWarbandByQuestName(wbName2);
		end
		if(wb==nil and target~=nil) then
			wb = GetWarbandByTarget(targetname);
			if(wb~=nil) then
				if(Preferences.debug==true) then  Turbine.Shell.WriteLine("<rgb=#FF5CCD>Collectible trouvé : "..wb.name); end		
				self.qsBubble:SetVisible(false);
				self.qsLbl:SetVisible(false);
				self.bubble = createBubblePopupForSharing(TRAD("Ohhhh, un collectible !\nVoulez-vous noter sa d\195\169couverte automatiquement ?", "Wouh a collectible !\nDo you want to note its discovery automatically?"), FromUTF8(TRAD("a trouvé le collectible \"".. targetname .."\" près de ;loc.", "found the collectible \"".. targetname .."\" near ;loc.")), "/e", TRAD("Ho que oui !", "Ohhhh yeah !"));
				return;
			end
		end		
		if(wb == nil) then
			--Turbine.Shell.WriteLine("<rgb=#FF5CCD>Erreur, aucune troupe de guerre ou Menace itin\195\169rante du nom de "..targetname.." trouv\195\169e. Cette Troupe est donc ignor\195\169e!</rgb>");				
			if(self.bubble~=nil) then self.bubble:SetVisible(false); end
			self.qsBubble:SetVisible(false);
			self.qsLbl:SetVisible(false);
		else
			local message;
			if(wb.enemyType==2) then
				message = TRAD(FromUTF8("La menace itinérante "), "The roving threat ");
			else
				message = TRAD("La troupe de guerre ", "The warband ");
			end
			local canal = TRAD("/monde", "/world");
			if(Preferences.chatCanal==TRAD("Canal R\195\169gional", "Regional channel")) then
				canal = TRAD(FromUTF8("/régional"), "/regional");
			elseif(Preferences.chatCanal==TRAD("Canal de Confr\195\169rie", "Kinship channel")) then
				canal = "/k";
			elseif(Preferences.chatCanal==TRAD("Canal de Communaut\195\169", "Fellowship channel")) then
				canal = "/f";
			elseif(Preferences.chatCanal==TRAD("Canal du Raid", "Raid channel")) then
				canal = "/ra";
			end
			
			message = message..FromUTF8(wb.name) ..TRAD(FromUTF8(" a été repérée !"), " was spotted !");
			self.qsBubble:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, 
			canal.." <rgb=#FF5CCD>".. message .."\n=> ;loc</rgb>"));	
			self.qsBubble:SetVisible(true);
			self.qsLbl:SetVisible(true);
			warbandsDialog:FocusOnWarband(wb);
		end
	else
		if(self.bubble~=nil) then self.bubble:SetVisible(false); end
		self.qsBubble:SetVisible(false);
		self.qsLbl:SetVisible(false);
	end
end