import "WalmPlugins.WarbandsSlayer.src.WarbandSubPane";
import "WalmPlugins.WarbandsSlayer.src.InterNode";
import "WalmPlugins.WarbandsSlayer.src.TextNode";
import "WalmPlugins.WarbandsSlayer.src.SwitchLabel";
import "WalmPlugins.WarbandsSlayer.src.MiniMapViewer";
import "WalmPlugins.WarbandsSlayer.src.ProgressBar";
import "WalmPlugins.WarbandsSlayer.src.DiaryEntryNode";

WarbandPane = class( Turbine.UI.Label );

function WarbandPane:Constructor(width, height)	  	
	Turbine.UI.Label.Constructor( self );    	
	self:SetSize( width, height );
	
	self.header = Turbine.UI.Control();
	self.header:SetParent( self );
	self.header:SetSize(378, 92);
	self.header:SetPosition((width-378)/2, 2);	
	self.header:SetMouseVisible( false );
	self.header:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	self.header:SetBackground("WalmPlugins/WarbandsSlayer/resources/header_details2.tga");
	
	self.frame = Turbine.UI.Control();
	self.frame:SetParent( self );
	self.frame:SetSize(62, 62);
	self.frame:SetPosition((width-62)/2, 2);	
	self.frame:SetMouseVisible( false );
	self.frame:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );	
	
	self.difficultyIcone = Turbine.UI.Control();
	self.difficultyIcone:SetParent( self );
	self.difficultyIcone:SetSize(34, 44);
	self.difficultyIcone:SetPosition(width-40, 2);	
	self.difficultyIcone:SetMouseVisible( false );
	self.difficultyIcone:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );		
	
	self.wbName = Turbine.UI.Label();
	self.wbName:SetParent( self );
	self.wbName:SetSize(width-30, 31);
	self.wbName:SetPosition(15, 63);
	self.wbName:SetFont(Turbine.UI.Lotro.Font.TrajanProBold16);	
	self.wbName:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	self.wbName:SetMouseVisible( false );
	self.wbName:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	--self.wbName:SetBackColor( Turbine.UI.Color( 0.5, 0.5, 0.5 ) );

	self.wbPlace = Turbine.UI.Label();
	self.wbPlace:SetParent( self );
	self.wbPlace:SetSize(152, 32);
	self.wbPlace:SetPosition(5, 10);
	self.wbPlace:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);	
	self.wbPlace:SetMouseVisible( false );
	self.wbPlace:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	self.wbPlace:SetForeColor(Turbine.UI.Color( 1, 1, 0.5 ));
	
	self.treeView = Turbine.UI.TreeView();
    self.treeView:SetParent( self );
    self.treeView:SetPosition( self.header:GetLeft(), self.header:GetTop()+self.header:GetHeight()+10 );
    self.treeView:SetSize( self.header:GetWidth()-10, self:GetHeight()-self.treeView:GetTop() );
    self.treeView:SetIndentationWidth( 15 );
	
	treeViewScrollBar = Turbine.UI.Lotro.ScrollBar();
    treeViewScrollBar:SetOrientation( Turbine.UI.Orientation.Vertical );
    treeViewScrollBar:SetParent( self );
    treeViewScrollBar:SetPosition( self.treeView:GetLeft()+self.treeView:GetWidth(), self.treeView:GetTop() );
    treeViewScrollBar:SetSize( 10, self.treeView:GetHeight() );
	self.treeView:SetVerticalScrollBar( treeViewScrollBar );
	
	self:SetVisible(false);
end

function WarbandPane:SetHeight2(height)
	self:SetHeight(height);
	self.treeView:SetHeight(self:GetHeight()-self.treeView:GetTop());
	self.treeView:GetVerticalScrollBar():SetHeight(self:GetHeight()-self.treeView:GetTop());	
end

function WarbandPane:SetWarband(warband, wbCooldown, mapName)
	if(warband == nil) then
		self:SetVisible(false);
		return;
	end
	self:SetVisible(true);
	-- if(self.wb == warband) then
		-- return;
	-- end
	
	if(warband.frame==nil) then
		self.frame:SetBackground("WalmPlugins/WarbandsSlayer/resources/frames/default.tga");
	else
		self.frame:SetBackground("WalmPlugins/WarbandsSlayer/resources/frames/"..warband.frame);
	end
	self.wbPlace:SetText(mapName);
	if(warband.level~=nil and warband.level>0) then
		self.wbName:SetText("["..warband.level.."] "..warband.name);
	else
		self.wbName:SetText(warband.name);
	end
	self.difficultyIcone:SetBackground("WalmPlugins/WarbandsSlayer/resources/difficulty/"..(warband.size or "1").."_large.tga");
	
	self.treeView:GetNodes():Clear();
	
	self:CreateInfoNode(warband, wbCooldown, mapName)
	self:CreateProgressionNode(warband, wbCooldown, mapName)
	self:CreateLocalisationNode(warband, wbCooldown, mapName);
	self:CreateDetailsNode(warband, wbCooldown, mapName);
	self:CreateStatsNode(warband, wbCooldown, mapName);
	self:CreateRewardsNode(warband, wbCooldown, mapName);
	
	self.wb = warband;
	self.treeView:ExpandAll();	
end
function WarbandPane:CreateInfoNode(warband, wbCooldown, mapName)
	local rootNodes = self.treeView:GetNodes();
	if(warband.description~=nil and string.len(warband.description)>0) then	
		local gNode = DiaryEntryNode(self.treeView:GetWidth()-15);
		gNode:SetFore(Turbine.UI.Color(1, 1, 1), Turbine.UI.Lotro.Font.Verdana14);
		gNode:UpdateText(warband.description);
		local node = AreaNode("Description");
		node:GetChildNodes():Add(gNode);
		rootNodes:Add( node );
		rootNodes:Add(InterNode(10));
	end	
	if(warband.how~=nil) then	
		local gNode = DiaryEntryNode(self.treeView:GetWidth()-15);
		gNode:SetFore(Turbine.UI.Color(1, 1, 1), Turbine.UI.Lotro.Font.Verdana14);
		gNode:UpdateText(warband.how);
		local node = AreaNode(TRAD("Que faut-il faire ?","What should be done ?"));
		node:GetChildNodes():Add(gNode);
		rootNodes:Add( node );
		rootNodes:Add(InterNode(10));
	end
	if(warband.serie~=nil) then	
		local gNode = DiaryEntryNode(self.treeView:GetWidth()-15);
		gNode:SetFore(Turbine.UI.Color(1, 1, 1), Turbine.UI.Lotro.Font.Verdana14);
		local node = AreaNode(TRAD("O\195\185 d\195\169marrer la s\195\169rie ?","Where to start the series?"));
		local msg = "";
		if(warband.serie.name~=nil) then msg=msg..TRAD("S\195\169rie de qu\195\170te : \"", "Quest line : \"")..warband.serie.name.."\".\n"; end
		if(warband.serie.pnj~=nil) then msg=msg..TRAD("Donn\195\169e par ", "Given by")..warband.serie.pnj; end
		if(warband.serie.loc~=nil) then msg=msg.." ("..warband.serie.loc..")."; end
		gNode:UpdateText(msg);
		node:GetChildNodes():Add(gNode);
		rootNodes:Add( node );
		rootNodes:Add(InterNode(10));
	end
	if(warband.quest~=nil) then	
		local gNode = DiaryEntryNode(self.treeView:GetWidth()-15);
		gNode:SetFore(Turbine.UI.Color(1, 1, 1), Turbine.UI.Lotro.Font.Verdana14);
		local node = AreaNode(TRAD("O\195\185 prendre la qu\195\170te ?", "Where to take the quest?"));
		local msg = "";
		if(warband.quest.given~=nil) then msg=msg..TRAD("Donn\195\169e ", "Given ")..warband.quest.given; end
		if(warband.quest.pnj~=nil) then msg=msg..TRAD("Donn\195\169e par ", "Given by ")..warband.quest.pnj; end
		if(warband.quest.loc~=nil) then msg=msg.." ("..warband.quest.loc..")."; end
		gNode:UpdateText(msg);
		node:GetChildNodes():Add(gNode);
		rootNodes:Add( node );
		rootNodes:Add(InterNode(10));
	end
	if(warband.check~=nil) then	
		local gNode = DiaryEntryNode(self.treeView:GetWidth()-15);
		gNode:SetFore(Turbine.UI.Color(1, 1, 1), Turbine.UI.Lotro.Font.Verdana14);
		local node = AreaNode(TRAD("Comment v\195\169rifier sa completion ?", "How to check its completion?"));
		local msg = "";
		if(warband.check.qdiary~=nil) then msg=msg..TRAD("> Dans le journal de qu\195\170tes (touche L par d\195\169faut), en cochant \"Voir les qu\195\170tes termin\195\169es\", dans la cat\195\169gorie \"", "> In the Quest Log (key L by default), by checking \"Show completed\", and in the category \"")..warband.check.qdiary.."\".\n\n"; end
		if(warband.check.ddiary~=nil) then msg=msg..TRAD("> Dans le journal de prouesses (touche MAJ+L par d\195\169faut), dans l'onglet \"Classe/Race/Epique\", choisissez \"Epique\" puis cochez \"Termin\195\169\" et cherchez l'entr\195\169e \"", "> In the Deed Log (key SHIFT+L by default), in the tab \"Class/Race/Epic\", choose \"Epic\" then check \"Completed\" and search \"")..warband.check.ddiary.."\".\n\n"; end
		if(warband.check.cdiary~=nil) then msg=msg..TRAD("> Dans le journal de prouesses (touche MAJ+L par d\195\169faut), dans l'onglet \"Classe/Race/Epique\", choisissez \"Classe\" puis cochez \"Termin\195\169\" et cherchez l'entr\195\169e \"", "> In the Deed Log (key SHIFT+L by default), in the tab \"Class/Race/Epic\", choose \"Class\" then check \"Completed\" and search \"")..warband.check.cdiary.."\".\n\n"; end
		if(warband.check.adiary~=nil) then msg=msg..TRAD("> Dans le journal de prouesses (touche MAJ+L par d\195\169faut), dans l'onglet \"", "> In the Deed Log (key SHIFT+L by default), in the tab \"")..warband.check.adiary..TRAD("\",  cochez \"Termin\195\169\" et cherchez l'entr\195\169e.\n\n", "then check \"Completed\" and search the entry.\n\n"); end
		if(warband.check.default) then msg=msg..warband.check.default end
		gNode:UpdateText(msg);
		node:GetChildNodes():Add(gNode);
		rootNodes:Add( node );
		--rootNodes:Add(InterNode(10));
	end
	if(warband.todo~=nil) then	
		local gNode = DiaryEntryNode(self.treeView:GetWidth()-15);
		gNode:SetFore(Turbine.UI.Color(1, 1, 1), Turbine.UI.Lotro.Font.Verdana14);
		local node = AreaNode(TRAD("Que faire ?", "What to do ?"));
		gNode:UpdateText(warband.todo);
		node:GetChildNodes():Add(gNode);
		rootNodes:Add( node );
		rootNodes:Add(InterNode(10));
	end
end
function WarbandPane:CreateProgressionNode(warband, wbCooldown, mapName)
	local rootNodes = self.treeView:GetNodes();
	local progressNode = AreaNode("Progression :");
	if(warband.repeatable~=nil) then		
		local days = {TRAD("dimanches","sundays"), TRAD("lundis","mondays"), TRAD("mardis","tuesdays"), TRAD("mercredis","wednesdays"), TRAD("jeudis","thursdays"), TRAD("vendredis","fridays"), TRAD("samedis","saturdays"), TRAD("jours","days"), TRAD("jeudis et dimanches","thursdays and sundays")};
		local gNode = DiaryEntryNode(self.treeView:GetWidth()-15);
		gNode:SetFore(Turbine.UI.Color(0, 1, 0), Turbine.UI.Lotro.Font.Verdana12, Turbine.UI.ContentAlignment.TopCenter);
		local reinitTxt=TRAD("R\195\169initialisation tous les ", "Reset all ")..days[warband.repeatable]..TRAD(" \195\160 ", " at ")..Preferences.utcResetHour.."h00."
		local currentGameTime = Turbine.Engine.GetLocalTime();
		local gNode2 = nil;
		if(wbCooldown~=nil and wbCooldown.resetTime~=nil and wbCooldown.resetTime>currentGameTime) then
			gNode2 = DiaryEntryNode(self.treeView:GetWidth()-15);
			gNode2:SetFore(Turbine.UI.Color(0, 1, 0), Turbine.UI.Lotro.Font.Verdana12, Turbine.UI.ContentAlignment.TopCenter);
			currentGameTime=wbCooldown.resetTime-currentGameTime;
			local dmin = math.floor(currentGameTime/60)%60;
			local dhour = math.floor(currentGameTime/60/60)%24;
			local dday = math.floor(currentGameTime/60/60/24);
			if(dday>0) then 
				if(dhour<10) then dhour="0"..dhour; end
				gNode2:UpdateText(TRAD("Dans "..dday.." jours et "..dhour.." heures.", "In "..dday.." days and "..dhour.." hours."));
			else
				if(dmin<10) then dmin="0"..dmin; end
				gNode2:UpdateText(TRAD("Dans "..dhour.."h"..dmin..".", "In "..dhour.."h"..dmin.."."));
			end
		end		
		gNode:UpdateText(reinitTxt);		
		progressNode:GetChildNodes():Add(gNode);			
		if(gNode2~=nil) then progressNode:GetChildNodes():Add(gNode2);  end
		progressNode:GetChildNodes():Add(InterNode(4));
	end
	if(warband.inc~=nil) then		
		if(warband.inc.max~=nil and warband.inc.max>1)then
			local barNode = Turbine.UI.TreeNode();
			barNode:SetSize( 350, 30 );
			barNode:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
			progressNode:GetChildNodes():Add(barNode);
			local pgbar = ProgressBar(250, warband.inc.max);
			pgbar:SetParent(barNode);
			pgbar:SetPosition(50, 0);
			if(wbCooldown~=nil) then
				pgbar:UpdateValue(wbCooldown.value);
			end
		end
		if(warband.inc.progressMax~=nil)then
			local barNode = Turbine.UI.TreeNode();
			barNode:SetSize( 350, 30 );
			barNode:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
			progressNode:GetChildNodes():Add(barNode);
			local pgbar = ProgressBar(250, warband.inc.progressMax);
			pgbar:SetParent(barNode);
			pgbar:SetPosition(50, 4);
			if(wbCooldown~=nil) then
				pgbar:UpdateValue(wbCooldown.progress or 0);
			end
			local arrowLeft = Turbine.UI.Label();
			arrowLeft:SetParent(barNode);
			arrowLeft:SetSize(32, 32);
			arrowLeft:SetPosition(39, 0);
			arrowLeft:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
			arrowLeft:SetBackground("WalmPlugins/WarbandsSlayer/resources/progressbar/Arrow_Gold_Left.tga");
			arrowLeft:SetVisible(wbCooldown~=nil and (wbCooldown.progress~=nil or wbCooldown.progress>0));
			local arrowsLeft = Turbine.UI.Label();
			arrowsLeft:SetParent(barNode);
			arrowsLeft:SetSize(32, 32);
			arrowsLeft:SetPosition(0, 0);
			arrowsLeft:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
			arrowsLeft:SetBackground("WalmPlugins/WarbandsSlayer/resources/progressbar/Arrows_Gold_Left.tga");
			arrowsLeft:SetVisible(wbCooldown~=nil and (wbCooldown.progress~=nil or wbCooldown.progress>0));			
			local arrowRight = Turbine.UI.Label();
			arrowRight:SetParent(barNode);
			arrowRight:SetSize(32, 32);
			arrowRight:SetPosition(350-32-38, 0);
			arrowRight:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
			arrowRight:SetBackground("WalmPlugins/WarbandsSlayer/resources/progressbar/Arrow_Gold_Right.tga");
			arrowRight:SetVisible(wbCooldown==nil or wbCooldown.progress==nil or wbCooldown.progress<warband.inc.progressMax);
			local arrowsRight = Turbine.UI.Label();
			arrowsRight:SetParent(barNode);
			arrowsRight:SetSize(32, 32);
			arrowsRight:SetPosition(350-38, 0);
			arrowsRight:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
			arrowsRight:SetBackground("WalmPlugins/WarbandsSlayer/resources/progressbar/Arrows_Gold_Right.tga");
			arrowsRight:SetVisible(wbCooldown==nil or wbCooldown.progress==nil or wbCooldown.progress<warband.inc.progressMax-10);			
			arrowLeft.MouseClick = function() warbandsDialog:AddPromotionCooldown(-1); end		
			arrowsLeft.MouseClick = function() warbandsDialog:AddPromotionCooldown(-10); end		
			arrowRight.MouseClick = function() warbandsDialog:AddPromotionCooldown(1); end		
			arrowsRight.MouseClick = function() warbandsDialog:AddPromotionCooldown(10); end		
		end		
		if(warband.inc.updatefct~=nil) then
			local updateNode = Turbine.UI.TreeNode();
			updateNode:SetSize( 350, 20 );
			updateNode:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
			progressNode:GetChildNodes():Add(updateNode);
			local updateButton = Turbine.UI.Lotro.Button();
			updateButton:SetParent( updateNode );
			updateButton:SetText(TRAD("Mettre \195\160 jour", "Update"));
			updateButton:SetSize(120, 16);
			updateButton:SetPosition((350-120)/2, 0);
			updateButton.MouseClick = warband.inc.updatefct;
			rootNodes:Add(progressNode);
			rootNodes:Add(InterNode(10));
		end	
		if(warband.inc.validatefct~=nil or warband.inc.completefct~=nil) then
			local updateNode = Turbine.UI.TreeNode();
			updateNode:SetSize( 350, 20 );
			updateNode:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
			progressNode:GetChildNodes():Add(updateNode);
			local updateButton = Turbine.UI.Lotro.Button();
			updateButton:SetParent( updateNode );
			if(warband.inc.completefct~=nil or wbCooldown==nil or wbCooldown.value==nil or wbCooldown.value==0) then 
				updateButton:SetText(TRAD("Valider la completion", "Validate completion"));
			else
				updateButton:SetText(TRAD("Annuler la completion", "Cancel completion"));
			end
			updateButton:SetSize(160, 16);
			updateButton:SetPosition((350-160)/2, 0);
			updateButton.MouseClick = function()
				if(warband.inc.completefct~=nil or wbCooldown==nil or wbCooldown.value==nil or wbCooldown.value==0) then 
					if(warband.inc.completefct==nil) then updateButton:SetText(TRAD("Annuler la completion", "Cancel completion")); end
					warbandsDialog:AddCooldown(self.wb, warband.id, true, true, 1);									
				else
					updateButton:SetText(TRAD("Valider la completion", "Validate completion"));
					warbandsDialog:AddCooldown(self.wb, warband.id, true, true, 0);					
				end
			end
		end		
		if(warband.updateMsg~=nil) then
			local msg = warband.updateMsg;
			if(msg=="LVL") then msg = TRAD("Se met \195\160 jour automatiquement \195\160 chaque gain de niveau.\nVous pouvez toutefois le mettre \195\160 jour avec le bouton ci-dessus.", "Automatically updated each time you level up.\nYou can however update it with the button above."); end
			if(msg=="GB") then msg = TRAD("Se met \195\160 jour automatiquement lors de gain de Point de Promotion.\nVous pouvez toutefois le mettre \195\160 jour manuellement.", "Automatically updated each time you get a Promotion Point.\nYou can however update it with the button above."); end
			if(msg=="DO") then msg = TRAD("Se met \195\160 jour automatiquement \195\160 la compl\195\168tion.\nSi vous l'avez d\195\169j\195\160 finie, vous pouvez la valider manuellement.", "Automatically updated at completion. If you have already finished it, you can validate it manually."); end
			local gNode = DiaryEntryNode(self.treeView:GetWidth()-15);
			gNode:SetFore(Turbine.UI.Color(1, 1, 1), Turbine.UI.Lotro.Font.Verdana12, Turbine.UI.ContentAlignment.TopCenter);
			gNode:UpdateText(msg);
			progressNode:GetChildNodes():Add(gNode);
		end			
	end
	if(warband.custom==true) then
		local updateNode = Turbine.UI.TreeNode();
		updateNode:SetSize( 350, 20 );
		updateNode:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
		progressNode:GetChildNodes():Add(updateNode);
		local updateButton = Turbine.UI.Lotro.Button();
		updateButton:SetParent( updateNode );
		updateButton:SetText(TRAD("Supprimer la r\195\169p\195\169table", "Remove the repetable"));
		updateButton:SetSize(160, 16);
		updateButton:SetPosition((350-160)/2, 0);
		updateButton.MouseClick = function()
			warbandsDialog:RemoveCooldown(warband.id, true);
			for i, reg in ipairs(wadData) do
				if(reg.insertCustoms==true and reg.areas~=nil) then
					for j, area in ipairs(reg.areas) do
						for k, wb in ipairs(area.wads) do
							if(wb~=nil and wb.id==warband.id) then
								table.remove(area.wads, k);
								break;
							end
						end
					end
				end
			end
			for i, wad in ipairs(Preferences.custWad) do
				if(wad~=nil and wad.id==warband.id) then
					table.remove(Preferences.custWad, i);
					break;
				end
			end
			SavePreferences();
			warbandsDialog:UpdateBOF();
			warbandsDialog:PopupateTreeView();
			warbandsDialog:ShowAllWarbands();
			warbandsDialog:LoadCooldowns();
			warbandsDialog:ShowEnemyTab(5);
		end
	end		
	if(progressNode:GetChildNodes():GetCount()>0) then
		rootNodes:Add(progressNode);
		rootNodes:Add(InterNode(10));
	end	
end
function WarbandPane:CreateLocalisationNode(warband, wbCooldown, mapName)
	local rootNodes = self.treeView:GetNodes();
	
	if(warband.note~=nil) then
		local noteNode = TextNode(warband.note, nil, 360, 32);
		noteNode.labelKey:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
		noteNode.labelKey:SetForeColor(Turbine.UI.Color( 1.0, 0.0, 0.0 ));
		rootNodes:Add( noteNode );
	end
	
	local node = AreaNode(TRAD("Localisation", "Location"));
	
	if(warband.loc~=nil) then
		local locationNode = TextNode(TRAD("Coordonn\195\169es:", "Coordinates:"), warband.loc);
		node:GetChildNodes():Add(locationNode);
	end
	if(warband.closedPOI~=nil and warband.closedPOI~="TBD") then
		local localisationPOINode = TextNode(TRAD(ToUTF8("A ct de:"), "Close to:"), warband.closedPOI);
		node:GetChildNodes():Add(localisationPOINode);
	end
	if(warband.spawnShared~=nil) then
		spawnsharedNode = TextNode(TRAD("Spawn commun:", "Common spawn:"), warband.spawnShared);
		node:GetChildNodes():Add(spawnsharedNode);
	end
	
	local mapTitleNode = AreaNode(TRAD("Carte", "Map"));
	if(warband.poi~=nil or warband.loc~=nil or warband.multipoi~=nil or warband.rovingThreatData) then
		local mapNode = Turbine.UI.TreeNode();
		mapNode:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
		mapNode:SetMouseVisible( false );
		self.mapsList = {};
		if(warband.poi~=nil or warband.loc~=nil) then
			local mapViewer = MiniMapViewer(mapNode, true);
			if mapViewer:UpdateMap(warband, nil, nil, true) == true then
				mapNode:SetSize( mapViewer:GetSize() );
				table.insert(self.mapsList, mapViewer);
			end
		elseif(warband.multipoi ~= nil) then
			local dec=0;
			for i=1 , table.getn(warband.multipoi), 1 do
				if(warband.multipoi[i].mapName~=nil) then
					local nameLabel = Turbine.UI.Label(); 
					nameLabel:SetParent( mapNode );
					--nameLabel:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
					nameLabel:SetSize(300, 16);
					nameLabel:SetPosition( 0, 228*(i-1)+dec );
					dec = dec+nameLabel:GetHeight();
					nameLabel:SetText(warband.multipoi[i].mapName..":");	
				end
				local mapViewer = MiniMapViewer(mapNode, true, i, dec);
				table.insert(self.mapsList, mapViewer);
				mapViewer:UpdateMap(warband, i);
			end
			mapNode:SetSize( 304, table.getn(warband.multipoi)*228+5+dec);		
		end	
		mapTitleNode:GetChildNodes():Add(mapNode);
	end
	if(mapTitleNode:GetChildNodes():GetCount()>0) then
		node:GetChildNodes():Add(mapTitleNode);
	end
	
	if(warband.pnj ~= nil) then
		node:GetChildNodes():Add(TextNode(TRAD("PNJ de Qu\195\170te:", "Quest Giver:"), warband.pnj, 340, 16));	
	end	
	
	if(node:GetChildNodes():GetCount()>0) then
		rootNodes:Add( node );	
		rootNodes:Add(InterNode(10));
	end
end

function WarbandPane:CreateDetailsNode(warband, wbCooldown, mapName)
	local rootNodes = self.treeView:GetNodes();
	local infoNode = AreaNode("Informations");
	
	if(warband.race~=nil) then
		local locationNode = TextNode("Race:", warband.race);
		infoNode:GetChildNodes():Add(locationNode);
	end
	if(warband.moral~=nil) then
		local moralTxt = warband.moral or "Unknown";
		if(warband.difficulty~=nil) then moralTxt=moralTxt.." ("..warband.difficulty.name..")"; end
		local locationNode = TextNode("Moral:", moralTxt);
		infoNode:GetChildNodes():Add(locationNode);
	end

	if(warband.adds~=nil) then
		local addsTitleNode = AreaNode("Adds");
		local count = 0;
		for i=1, table.getn(warband.adds), 1 do
			local adds = warband.adds[i];
			local libelle = adds[1].." "..adds[2];
			if(adds[3]~=nil) then
				libelle = libelle.." ("..adds[3].name..")";
			end
			addsTitleNode:GetChildNodes():Add(TextNode(libelle));
			count = count + adds[1];
		end
		local endtitle = "";
		if(warband.addlinked == true) then
			endtitle = TRAD(" <<Li\195\169s au boss>>", " <<Linked to the boss>>");
		end
		addsTitleNode:SetValue("Adds [".. count .."]"..endtitle);
		infoNode:GetChildNodes():Add(addsTitleNode);
	end
	
	if(infoNode:GetChildNodes():GetCount()>0) then
		rootNodes:Add( infoNode );
		rootNodes:Add(InterNode(10));
	end
end

function WarbandPane:CreateStatsNode(warband, wbCooldown, mapName)
	if(warband.hideStats==true) then return; end
	local rootNodes = self.treeView:GetNodes();
	local statNode = AreaNode(TRAD("Statistiques", "Statistics"));
	
	if(warband.enemyType==4 or warband.enemyType==3) then
		if(wbCooldown~=nil) then
			local digit = ""; if(wbCooldown[2].Minute<10)then digit="0";end
			statNode:GetChildNodes():Add(TextNode(TRAD("Mis \195\160 jour le "..wbCooldown[2].Day.."/"..wbCooldown[2].Month.."/"..wbCooldown[2].Year.." \195\160 ","Updated the "..wbCooldown[2].Month.."/"..wbCooldown[2].Day.."/"..wbCooldown[2].Year.." at ")..wbCooldown[2].Hour.."h"..digit..wbCooldown[2].Minute));
		end
	else
		local action1 = TRAD("Termin\195\169", "Accomplished");
		local action2 = TRAD("termin\195\169", "accomplished");
		if(warband.enemyType~=5) then action=TRAD("Tu\195\169", "Killed"); action=TRAD("tu\195\169", "killed"); end
		if(wbCooldown ~= nil) then
			local digit = ""; if(wbCooldown[2].Minute<10)then digit="0";end
			statNode:GetChildNodes():Add(TextNode(action1..TRAD(" le "..wbCooldown[2].Day.."/"..wbCooldown[2].Month.."/"..wbCooldown[2].Year.." \195\160 ", " the "..wbCooldown[2].Month.."/"..wbCooldown[2].Day.."/"..wbCooldown[2].Year.." at ")..wbCooldown[2].Hour.."h"..digit..wbCooldown[2].Minute));
			if(wbCooldown[3]~=nil) then statNode:GetChildNodes():Add(TextNode(action1.." ".. wbCooldown[3] .. TRAD(" fois", " times"))); end
		else
			statNode:GetChildNodes():Add(TextNode(TRAD("Vous ne l'avez jamais ", "You never ")..action2.." :/"));
		end		
	end
	if(statNode:GetChildNodes():GetCount()>0) then
		rootNodes:Add( statNode );
		rootNodes:Add(InterNode(10));	
	end
end

function WarbandPane:OnPOIUpdated(wad, poi)
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		if(self.treeView:GetNodes():Get(i).OnPOIUpdated~=nil) then
			self.treeView:GetNodes():Get(i):OnPOIUpdated(wad, poi);
		end
	end
end

function WarbandPane:CreateRewardsNode(warband, wbCooldown, mapName)
	if(warband.rewards~=nil and table.getn(warband.rewards)>0) then
		local rootNodes = self.treeView:GetNodes();
		local node = AreaNode( TRAD("R\195\169compenses" , "Rewards"));
		rootNodes:Add( node );
		
		local rewardsNode = Turbine.UI.TreeNode();
		rewardsNode:SetSize( 350, 40 );
		rewardsNode:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
		--rewardsNode:SetBackColor( Turbine.UI.Color( 0.2, 0.2, 0.2 ) );
		node:GetChildNodes():Add(rewardsNode);
		
		local rewardFrameLabel = Turbine.UI.Label();
		rewardFrameLabel:SetParent( rewardsNode );
		rewardFrameLabel:SetPosition(0, 0);
		rewardFrameLabel:SetSize(350, 40); --359
		rewardFrameLabel:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );	
		rewardFrameLabel:SetBackground("WalmPlugins/WarbandsSlayer/resources/rewardsframe.tga");
		rewardFrameLabel:SetMouseVisible( false );
		
		local limit = table.getn(warband.rewards);
		if(limit>8) then limit = 9; end
		for i=1 , limit , 1 do
			if(warband.rewards[i][1]~=nil and warband.rewards[i][1].picture~=nil) then
				local rewardLabel = Turbine.UI.Label();
				rewardLabel:SetParent( rewardFrameLabel );
				rewardLabel:SetPosition(12+(i-1)*38, 4);
				rewardLabel:SetSize(32, 32);
				rewardLabel:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
				rewardLabel:SetBackground("WalmPlugins/WarbandsSlayer/resources/"..warband.rewards[i][1].picture);
				if(warband.rewards[i][1].showQuantity == true) then
					local counter = Turbine.UI.Label();
					counter:SetParent(rewardLabel);
					counter:SetPosition(0, 8);
					counter:SetTextAlignment(Turbine.UI.ContentAlignment.BottomRight);
					counter:SetOutlineColor( Turbine.UI.Color( 0, 0, 0 ) );
					counter:SetFontStyle( Turbine.UI.FontStyle.Outline );
					counter:SetSize(29, 24);
					counter:SetText(warband.rewards[i][2]);
				end
				rewardLabel.tooltip = GenericTooltip(rewardLabel);
				if(warband.rewards[i][1].GetName~=nil) then
					rewardLabel.tooltip:AddPictureHeader("WalmPlugins/WarbandsSlayer/resources/"..warband.rewards[i][1].picture, warband.rewards[i][1]:GetName(warband.rewards[i][2], warband.rewards[i][3]));
				else
					rewardLabel.tooltip:AddPictureHeader("WalmPlugins/WarbandsSlayer/resources/"..warband.rewards[i][1].picture, warband.rewards[i][1].name);
				end
				if(warband.rewards[i][1].GetDescription~=nil) then
					rewardLabel.tooltip:AddLayer(warband.rewards[i][1]:GetDescription(warband.rewards[i][2], warband.rewards[i][3]), Turbine.UI.Color(197/255, 179/255, 88/255), nil, Turbine.UI.Lotro.Font.Verdana16);
				else
					rewardLabel.tooltip:AddLayer(warband.rewards[i][1].description, Turbine.UI.Color(197/255, 179/255, 88/255), nil, Turbine.UI.Lotro.Font.Verdana16);
				end	
			end
		end
	end
end

function WarbandPane:UpdatePlayerPosition(x, y)
	for i,map in ipairs(self.mapsList) do
		map:UpdatePlayerPosition(x, y);
	end	
end