

WarbandsDialog = class( Turbine.UI.Lotro.Window );
warbandsCooldowns = nil;
Filters = {
	show1 = false,
	show6 = false,
	todo = true,
	done = true,
	search = "",
	unrepeat = true
};

function WarbandsDialog:Constructor()
	Turbine.UI.Lotro.Window.Constructor( self );
	
	self:SetSize( 765, Preferences.main_height or 574 );
	self:SetVisible(false);

	self:ConstructTreeNode();	
	self:LoadFilters();	
	self:ImportCustomWads();
	self:PopupateTreeView();
	LoadPOI();		
	self:SetText( TRAD("Mort aux Troupes de Guerre !", "Warbands and Deeds Slayer") );	
	
	self.Closed = function(sender, args)
		self:Stop();
	end
	self.PositionChanged = function(sender, args)
		Preferences.main_x, Preferences.main_y = self:GetPosition();
		SavePreferences();
	end
	self.resizer = Turbine.UI.Label();
	self.resizer:SetParent( self );
	self.resizer:SetSize(100, 10);
	self.resizer:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	self.resizer:SetBackground("WalmPlugins/WarbandsSlayer/resources/v_resize.jpg");	
	self.resizer.MouseDown = function( sender, args )
		if(args.Button == Turbine.UI.MouseButton.Left) then
			sender.dragStartX = args.X;
			sender.dragStartY = args.Y;
			sender.dragging = true;
			sender.dragged = false;
		end
	end
	self.resizer.MouseUp = function( sender, args )
		if (args.Button == Turbine.UI.MouseButton.Left) then			
			if (sender.dragging) then
				sender.dragging = false;
			end
			Preferences.main_height = self:GetHeight();
			SavePreferences();
		end
	end
	self.resizer.MouseMove = function(sender,args)
		if ( sender.dragging ) then
			local height = self:GetHeight() + args.Y - sender.dragStartY;
			if(height>300) then 
				self:SetHeight(height);
			end
			self:UpdateResponsive();
		end
	end
	
	local hideUI = false;
	local wasVisible;
	self:SetWantsKeyEvents(true);
	self.KeyDown = function(sender, args)
		if (args.Action == 268435635) then
			if not hideUI then
				hideUI = true;
				if self:IsVisible() then
					wasVisible = true;
					self:SetVisible(false);					
				else
					wasVisible = false;
				end
			else
				hideUI = false;
				if wasVisible then
					self:SetVisible(true);				
				end
			end
		end
	end	
	
	self:CreateParametersButton();
	self:ConstructHeader();
	self:ConstructSearchComponents();
	self.warbandPane = WarbandPane(380, 433);
	self.warbandPane:SetParent( self );	
	self.warbandPane:SetPosition( 380, 105 );
	self:ShowAllWarbands();
	self:LoadCooldowns();		
	self:InitChatLogger();
	
	self:ApplyPreferences();
	self:ApplyFilters();
	self:ShowEnemyTab(Filters.tab);
	self:UpdateResponsive();
end	

function WarbandsDialog:ImportCustomWads()
	if(Preferences.custWad==nil or table.getn(Preferences.custWad)==0) then return; end
	for i, reg in ipairs(wadData) do
		if(reg.insertCustoms==true and reg.areas~=nil) then
			for j, area in ipairs(reg.areas) do
				if(area.insertCustoms==true and area.wads~=nil) then
					for k, cust in ipairs(Preferences.custWad) do
						table.insert(area.wads, cust );
					end
					return;
				end
			end
		end
	end	
end

function WarbandsDialog:ApplyPreferences()
	self:SetPosition(Preferences.main_x, Preferences.main_y);
	
	if(self.lastCdPref ~= Preferences.utcResetHour) then
		self:LoadCooldowns(); 
	end
	self.lastCdPref = Preferences.utcResetHour;
	
	self:SetWantsUpdates(Preferences.autoUpdate);
end

function WarbandsDialog:Update( args )
	--PrintDate(self.nextcd, "nextcd");
	if(Preferences.autoUpdate and CompareDate(self.nextcd)) then
		Turbine.Shell.WriteLine("<rgb=#FF5CCD>"..TRAD(ToUTF8("Rinitialisation des cooldowns des qutes"), "Resetting quests cooldowns").." !</rgb>");
		self:LoadCooldowns(); -- recalcul les cds		
	end
end

function WarbandsDialog:ConstructTreeNode()
	self.treeView = Turbine.UI.TreeView();
    self.treeView:SetParent( self );
    self.treeView:SetPosition( 10, 105 );
    self.treeView:SetSize( 350, 433 );
    self.treeView:SetIndentationWidth( 15 );
	local treeViewScrollBar = Turbine.UI.Lotro.ScrollBar();
    treeViewScrollBar:SetOrientation( Turbine.UI.Orientation.Vertical );
    treeViewScrollBar:SetParent( self );
    treeViewScrollBar:SetPosition( 360, 105 );
    treeViewScrollBar:SetSize( 10, 433 );
	self.treeView:SetVerticalScrollBar( treeViewScrollBar );
	self.treeView.SelectedNodeChanged = function(sender, args)
		local node = self.treeView:GetSelectedNode();		
		if(node~=nil and node.warband~=nil) then
			self.warbandPane:SetWarband(node.warband, self:GetWarbandCooldown(node.warband.id), node:GetParentNode():GetValue());
		end		
	end
end

function WarbandsDialog:CreateParametersButton()
	self.lowerSep = Turbine.UI.Control();
	self.lowerSep:SetParent( self );
	self.lowerSep:SetSize( self:GetWidth()-8 , 2 );
	self.lowerSep:SetPosition( 4, self:GetHeight()-34 );	
	self.lowerSep:SetBackColor( Turbine.UI.Color(0.5, 0.5, 0.5) );
	self.lowerSep:SetZOrder(99);

	self.createRepetableBtn = Turbine.UI.Lotro.Button();
    self.createRepetableBtn:SetParent( self );
    self.createRepetableBtn:SetPosition( 40, 545 );
    self.createRepetableBtn:SetSize( 180, 18 );
    self.createRepetableBtn:SetText(TRAD(ToUTF8("Ajouter une rptable"), "Add a repetable"));
	self.createRepetableBtn.Click = function( sender, args )
		self.repetEditor = CustomRepetableWindow();
		self.repetEditor:SetVisible(true);
		self.repetEditor:Activate();
	end

	self.optionbtn = Turbine.UI.Lotro.Button();
    self.optionbtn:SetParent( self );
    self.optionbtn:SetPosition( 640, 545 );
    self.optionbtn:SetSize( 90, 18 );
    self.optionbtn:SetText(TRAD(ToUTF8("Paramtres"), "Settings"));
	self.optionbtn.Click = function( sender, args )
		local configDialog = GetConfigurationDialogInstance();
		configDialog:SetVisible(true);
	end
end

function WarbandsDialog:ConstructHeader()
	local headerIco = Turbine.UI.Control();
	headerIco:SetParent( self );
	headerIco:SetSize( 756, 48 );
	headerIco:SetPosition( 5, 58 );
	headerIco:SetZOrder( -99);
	headerIco:SetBackground("WalmPlugins/WarbandsSlayer/resources/header2.tga");
	headerIco:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	
	local iconExpandAll = Turbine.UI.Control();
	iconExpandAll:SetParent( self );
	iconExpandAll:SetSize( 16, 16 );
	iconExpandAll:SetPosition( 16, 76 );
	iconExpandAll:SetBackground( 0x41007E27 );
	iconExpandAll:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );	
	iconExpandAll.MouseClick = function( sender, args )
		self:ShowAllWarbands();
	end

	local iconCollapseAll = Turbine.UI.Control();
	iconCollapseAll:SetParent( self );
	iconCollapseAll:SetSize( 16, 16 );
	iconCollapseAll:SetPosition( 38, 76 );
	iconCollapseAll:SetBackground( 0x41007E26 );
	iconCollapseAll:SetBlendMode( Turbine.UI.BlendMode.AlphaBlend );
	iconCollapseAll.MouseClick = function( sender, args )
		self:CollapseAllWarbands();
	end	
	
	local upperSep = Turbine.UI.Control();
	upperSep:SetParent( self );
	upperSep:SetSize( self:GetWidth()-8 , 2 );
	upperSep:SetPosition( 4, 102 );	
	upperSep:SetBackColor( Turbine.UI.Color(0.5, 0.5, 0.5) );
	upperSep:SetZOrder(99);
	
	self.warbandTab = TabButton(TRAD("Troupes de Guerre", "Warbands"), true);
	self.warbandTab:SetParent(self);
	self.warbandTab:SetPosition( 25, 38 );
	self.rovingThreatTab = TabButton(TRAD("Menaces itin\195\169rantes", "Roving Threats"), false);
	self.rovingThreatTab:SetParent(self);
	self.rovingThreatTab:SetPosition( 165, 38 );
	self.poitTab = TabButton(TRAD(ToUTF8("Points d'intert"), "Points of interest"), false);
	self.poitTab:SetParent(self);
	self.poitTab:SetPosition( 305, 38 );	
	self.pdcTab = TabButton(TRAD("Points de classe", "Class Traits points"), false);
	self.pdcTab:SetParent(self);
	self.pdcTab:SetPosition( 445, 38 );	
	self.richTab = TabButton("Farming", false);
	self.richTab:SetParent(self);
	self.richTab:SetPosition( 585, 38 );		
	self.warbandTab.MouseClick = function()
		self:ShowEnemyTab(1);
	end
	self.rovingThreatTab.MouseClick = function()
		self:ShowEnemyTab(2);
	end
	self.poitTab.MouseClick = function()
		self:ShowEnemyTab(3);
	end	
	self.pdcTab.MouseClick = function()
		self:ShowEnemyTab(4);
	end	
	self.richTab.MouseClick = function()
		self:ShowEnemyTab(5);
	end	
	self.warbandTab:SetSelected(Filters.tab==nil or Filters.tab==1);
	self.rovingThreatTab:SetSelected(Filters.tab==2);
	self.poitTab:SetSelected(Filters.tab==3);
	self.pdcTab:SetSelected(Filters.tab==4);
	self.richTab:SetSelected(Filters.tab==5);
	--self:ShowEnemyTab(1);
	self:ConstructFilters();
end

function WarbandsDialog:ShowEnemyTab(enemyTab)
	self.warbandPane:SetWarband(nil);
	if(enemyTab==nil) then
		enemyTab = 1;
	end
	if(enemyTab==1) then
		self:SetText(TRAD("Troupes de Guerre", "Warbands"));
	elseif(enemyTab==2) then
		self:SetText(TRAD("Menaces itin\195\169rantes", "Roving Threats"));
	elseif(enemyTab==3) then
		self:SetText(TRAD(ToUTF8("Points d'intert"), "Points of interest"));		
	elseif(enemyTab==4) then
		self:SetText(TRAD("Points de classe", "Class Traits points"));			
	elseif(enemyTab==5) then
		self:SetText("Farming");		
	end
	
	self.targetEriadorTgBtn:TabVisibility(enemyTab);
	self.targetRhovanionTgBtn:TabVisibility(enemyTab);
	self.targetGondorTgBtn:TabVisibility(enemyTab);
	self.targetMordorBtn:TabVisibility(enemyTab);
	self.rewardVertueBtn:TabVisibility(enemyTab);
	self.rewardBraisesBtn:TabVisibility(enemyTab);
	self.rewardGrainsBtn:TabVisibility(enemyTab);
	self.rewardTraceriesBtn:TabVisibility(enemyTab);
	self.rewardReputBtn:TabVisibility(enemyTab);
	self.customRepBtn:TabVisibility(enemyTab);
	
	Filters.tab = enemyTab;
	self.warbandTab:SetSelected(Filters.tab==nil or Filters.tab==1);
	self.rovingThreatTab:SetSelected(Filters.tab==2);
	self.poitTab:SetSelected(Filters.tab==3);
	self.pdcTab:SetSelected(Filters.tab==4);
	self.richTab:SetSelected(Filters.tab==5);	
	
	self:ApplyFilters();
	self:SaveFilters(false);
	self:ReloadCdCounters();
end

function WarbandsDialog:ConstructFilters()
	self.lvlp5 = ToggleButton	(32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_filter.jpg");
	self.lvlp5:SetParent( self );	
	self.lvlp5:SetPosition( 60, 68 );
	self.lvlp5:SetChecked(Filters.lvlp5==true);
	self.lvlp5.tooltip = GenericTooltip(self.lvlp5, TRAD("Niveaux -+6", "Levels -+6"), TRAD("Permet d'afficher les objectifs de niveaux proches (plus ou moins 6 niveaux).", "Allows you to display the objectives of similar levels (plus or minus 6 levels)."));
	self.lvlp5.Toggled = function(sender, selected)
		Filters.lvlp5 = selected;
		self:ApplyFilters();
		self:SaveFilters();
	end
	self.size1TgBtn = ToggleButton	(32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_size_1_off.jpg");
	self.size1TgBtn:SetParent( self );	
	self.size1TgBtn:SetPosition( 110, 68 );
	self.size1TgBtn:SetChecked(not Filters.show1 );
	self.size1TgBtn.tooltip = GenericTooltip(self.size1TgBtn, "Solo", TRAD("Permet d'afficher ou masquer les qu\195\170tes solotables.", "Allows you to show or hide solo quests."));
	self.size1TgBtn.Toggled = function(sender, selected)
		Filters.show1 = not selected;
		self:ApplyFilters();
		self:SaveFilters();
	end
	self.size6TgBtn = ToggleButton	(32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_size_6_off.jpg", Filters.show6);
	self.size6TgBtn:SetParent( self );	
	self.size6TgBtn:SetPosition( 146, 68 );
	self.size6TgBtn:SetChecked(not Filters.show6 );
	self.size6TgBtn.tooltip = GenericTooltip(self.size6TgBtn, TRAD("Communaut\195\169", "Fellowship"), TRAD("Permet d'afficher ou masquer les qu\195\170tes de communaut\195\169.", "Allows you to show or hide quests for fellowships."));
	self.size6TgBtn.Toggled = function(sender, selected)
		Filters.show6 = not selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end	
	self.doneTgBtn = ToggleButton (32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_done2.jpg");
	self.doneTgBtn:SetParent( self );	
	self.doneTgBtn:SetPosition( 232, 68 );
	self.doneTgBtn:SetVisible(not Preferences.win31Style);
	self.doneTgBtn.tooltip = GenericTooltip(self.doneTgBtn, TRAD("Qu\195\170tes faites", "Quests done"), TRAD(ToUTF8("Permet d'afficher ou masquer les qutes dj faites."), "Allows you to show or hide the quests already done."));
	self.doneTgBtn:SetChecked(Filters.done);
	self.doneTgBtn.Toggled = function(sender, selected)
		Filters.done = selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end
	self.todoTgBtn = ToggleButton (32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/btn_todo.jpg");
	self.todoTgBtn:SetParent( self );	
	self.todoTgBtn:SetPosition( 196, 68 );
	self.todoTgBtn:SetVisible(not Preferences.win31Style);
	self.todoTgBtn.tooltip = GenericTooltip(self.todoTgBtn, TRAD(ToUTF8("Qutes  faire"), "Quests to do"), TRAD("Permet d'afficher ou masquer les qu\195\170tes restant \195\160 faire.", "Allows you to display or hide the quests still to be done."));
	self.todoTgBtn:SetChecked(Filters.todo);
	self.todoTgBtn.Toggled = function(sender, selected)
		Filters.todo = selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end

	self.targetEriadorTgBtn = self:CreateRTButton("Eriador", TRAD("de l'", "from ").."Eriador", "filtre_northdowns.tga", "targetEriador", -1, 0, 0, 0, -1);
	self.targetRhovanionTgBtn = self:CreateRTButton("Rhovanion", TRAD("du ", "from ").."Rhovanion", "filtre_erohan.tga", "targetRhovanion", 0, 1, 1, 1, -1);
	self.targetGondorTgBtn = self:CreateRTButton("Gondor", TRAD("du ", "from ").."Gondor", "filtre_wgondor.tga", "targetGondor", 1, 2, 2, 2, -1);
	self.targetMordorBtn = self:CreateRTButton("Mordor", TRAD("du ", "from ").."Mordor", "filtre_mordor.tga", "filtre_fanorien", 2, 3, 3, 3, -1);
	
	self.rewardVertueBtn = self:CreateRTButton(TRAD("R\195\169compenses : XP de vertues", "Rewards : Virtue Traits XP"), TRAD("permettant d'obtenir des objets d'XP de vertues", "allowing you to obtain virtue XP items"), "btn_vertue.jpg", "filtre_rewardVertues", -1, -1, -1, -1, 0);
	self.rewardBraisesBtn = self:CreateRTButton(TRAD("R\195\169compenses : Braises", "Rewards : Embers"), TRAD("permettant d'obtenir des Braises", "allowing you to obtain Embers"), "bnt_braises.jpg", "filtre_rewardBraises", -1, -1, -1, -1, 1);
	self.rewardGrainsBtn = self:CreateRTButton(TRAD("R\195\169compenses : Grains", "Rewards : Motes"), TRAD("permettant d'obtenir des Grains", "allowing you to obtain Motes"), "btn_grains.jpg", "filtre_rewardGrains", -1, -1, -1, -1, 2);
	self.rewardTraceriesBtn = self:CreateRTButton(TRAD("R\195\169compenses : Runes d'am\195\169lioration", "Rewards : Enhancement Runes"), TRAD("permettant d'obtenir des Runes d'am\195\169lioration", "allowing you to obtain Enhancement Runes"), "btn_traceries.jpg", "filtre_rewardTraceries", -1, -1, -1, -1, 3);
	self.rewardReputBtn = self:CreateRTButton(TRAD("R\195\169compenses : R\195\169putation / All\195\169geance", "Rewards : Reputation / Allegiance"), TRAD("permettant d'obtenir des points de rputation, ou des objets d'All\195\169geance", "allowing you to obtain Reputation or Allegiance items"), "btn_reput.jpg", "filtre_rewardReput", -1, -1, -1, -1, 4);
	self.customRepBtn = self:CreateRTButton(TRAD("R\195\169p\195\169tables Ajout\195\169es", "Repetables added"), TRAD("permettant d'afficher ou non les rptables que vous avez crs.", "allowing you to show (or not) the repetables you created."), "btn_cust.jpg", "filtre_customrep", -1, -1, -1, -1, 5);
end

function WarbandsDialog:CreateRTButton(regionName, regionLName, btnpictName, filter, wbPos, rtPos, poiPos, pdcPos, classPos)
	local toggleButton = ToggleButton (32, 29, "WalmPlugins/WarbandsSlayer/resources/btn/"..btnpictName);

	toggleButton:SetParent( self );
	toggleButton.wbPos = wbPos;
	toggleButton.rtPos = rtPos;
	toggleButton.poiPos = poiPos;
	toggleButton.pdcPos = pdcPos;
	toggleButton.classPos = classPos;
	toggleButton:SetPosition( 282 + 35*wbPos, 68 );
	toggleButton:SetVisible(not Preferences.win31Style);
	toggleButton.tooltip = GenericTooltip(toggleButton, regionName, TRAD("Permet de se focaliser sur les objectifs ", "Allows you to focus on objectives ")..regionLName);
	toggleButton:SetChecked(Filters[filter]==nil or Filters[filter]==true);
	
	toggleButton.Toggled = function(sender, selected)
		Filters[filter] = selected;
		self:ApplyFilters();
		self:SaveFilters();		
	end	
	toggleButton.TabVisibility = function(params, tab)
		if(tab==1) then
			toggleButton:SetVisible(wbPos~=-1);
			toggleButton:SetPosition( 282 + 35*wbPos, 68 );
		elseif (tab==2) then
			toggleButton:SetVisible(rtPos~=-1);
			toggleButton:SetPosition( 282 + 35*rtPos, 68 );
		elseif (tab==3) then
			toggleButton:SetVisible(poiPos~=-1);
			toggleButton:SetPosition( 282 + 35*poiPos, 68 );
		elseif (tab==4) then
			toggleButton:SetVisible(pdcPos~=-1);
			toggleButton:SetPosition( 282 + 35*pdcPos, 68 );
		elseif (tab==5) then
			toggleButton:SetVisible(classPos~=-1);
			toggleButton:SetPosition( 282 + 35*classPos, 68 );
		end
	end
	return toggleButton;
end

function WarbandsDialog:InitChatLogger()	
	if(Turbine.Chat.receivedListerners == nil) then
		Turbine.Chat.receivedListerners = {};
		Turbine.Chat.Received = function (sender, args)
			for i, j in pairs(Turbine.Chat.receivedListerners) do
				j:OnReceived(sender, args);
			end
		end
		-- local tempMessage = tostring(args.Message);
	end
	if (Turbine.Chat.receivedListerners ~= nil) then
		for i, j in pairs(Turbine.Chat.receivedListerners) do
			if(j==self) then return; end
		end
		table.insert(Turbine.Chat.receivedListerners, self);
		--Turbine.Shell.WriteLine( "WarbandsDialog ECHO: "..table.getn(Turbine.Chat.receivedListerners));
	end
	Turbine.Chat.commWB_BOF_GetWBTraitCD = function()
		return self:GetWBTraitCD();
	end
end

function WarbandsDialog:OnReceived(sender, args)
	if args.ChatType == Turbine.ChatType.Quest then
		local tempMessage = tostring(args.Message);
		--Turbine.Shell.WriteLine("<rgb=#FF5CCD>WarbandsDialog ECHO : ".. tempMessage .."</rgb>");
		-- local x, y, wbName = string.find(tempMessage, TRAD("^Termin\195\169[\194\160%s]*:[\194\160%s]*Troupe de guerre[\194\160%s]*:(.*)$", "^Completed[\194\160%s]*:[\194\160%s]*Warband[\194\160%s]*:(.*)$"));			
		-- if(wbName ~= nil) then
			-- --Turbine.Shell.WriteLine("<rgb=#FF5CCD>wbName : "..wbName.."</rgb>");
			-- if(self:AddCooldown(nil, wbName)~=false) then
				-- return;
			-- end
		-- end
		x, y, wbName = string.find(tempMessage, TRAD("^Termin\195\169.*:\n(.*)$", "^Completed.*:\n(.*)$")); -- Termin:Mordechair, Flau de Lhingris
		if(wbName ~= nil) then
			if(self:AddCooldown(nil, wbName)~=false) then
				return;
			end
		end
		-- Putain de fix pour les bugs de Turbine de traductions !!!!
		x, y, wbName = string.find(tempMessage, TRAD("^Termin\195\169.*:.*Warband.*:(.*)$", "^Completed.*:.*Warband.*:(.*)$")); -- Termin:Warband: Adrjan the Brute	
		if(wbName ~= nil) then
			if(self:AddCooldown(nil, wbName)~=false) then
				return;
			end
		end

		local x2, y2, rtName = string.find(tempMessage, TRAD("^Termin\195\169[\194\160%s]*:[\194\160%s]*Menace itin\195\169rante[\194\160%s]*:(.*)$", "^Completed.*:.*Roving Threat.*:(.*)$"));
		if(rtName ~= nil) then
			if(self:AddCooldown(nil, rtName)~=false) then
				return;
			end
		end
		for i=1, table.getn(wadData), 1 do
			if(wadData[i].areas ~= nil) then
				for j=1, table.getn(wadData[i].areas), 1 do
					local area = wadData[i].areas[j];
					if(area.wads ~= nil) then
						for k=1, table.getn(area.wads), 1 do
							local wad = area.wads[k];
							if(wad.inc~=nil and wad.inc.trigger~=nil) then
								local x2, y2, rtName = string.find(tempMessage, wad.inc.trigger);
								if(x2~=nil) then
									self:AddCooldown(wad, wad.name, true, true, 1);
									return;
								end
							end
						end
					end
				end
			end
		end
	elseif args.ChatType == Turbine.ChatType.Advancement then
		local tempMessage = tostring(args.Message);
		local x, y, level = string.find(tempMessage, TRAD("^Vous avez atteint le niveau (%d+).", "^Your level has changed to (%d+)."));
		if(level ~= nil) then
			self:AddLevelCooldown(level);
			return;
		end	
		local x, y, pts = string.find(tempMessage, TRAD("^Vous avez gagn\195\169 (%d+) points? de promotion%.", "^You have gained (%d+) Promotion points?%."));
		-- Vous avez gagn 3 points de promotion. ^You have gained (%d+) Promotion points?%.
		if(pts ~= nil) then
			self:AddPromotionCooldown(tonumber (pts));
			return;
		end	
		-- local x, y, pts = string.find(tempMessage, "^Vous avez gagn\195\169 (%d+) point de promotion.");
		-- -- Vous avez gagn 1 point de promotion.
		-- if(pts ~= nil) then
			-- self:AddPromotionCooldown(tonumber(pts));
			-- return;
		-- end
	elseif args.ChatType==Turbine.ChatType.Emote and Filters.playerName~=nil then
		local tempMessage = tostring(args.Message);
		local x, y, collect, loc = string.find(tempMessage, Filters.playerName..TRAD(" a trouv\195\169 le collectible \"(.*)\" pr\195\168s de (.*)%.\n$", " found the collectible \"(.*)\" near (.*)%.\n$"));
		if(collect~=nil and loc~=nil) then
			local x, y, loc = string.find(loc, "(.* .*)$");
			if(loc ~= nil) then
				if(Preferences.debug==true) then 
					Turbine.Shell.WriteLine("<rgb=#FF0000>Found collectible at :"..loc);
				end
				local wb = GetWarbandByCollectible(collect, loc);
				if(wb==nil) then
					Turbine.Shell.WriteLine(TRAD("<rgb=#FF0000>Erreur : Aucune donn\195\169e trouv\195\169e concernant le collectible \""..FromUTF8(collect).."\" \195\160 ces coordonn\195\169es...\nIl est possible que :\n* vous ayez d\195\169j\195\160 d\195\169couvert ce collectible ;\n* que les coordonn\195\169es ne soient pas exactes ;\n* ou que vous soyez dans une zone instanci\195\169e</rgb>", "<rgb=#FF0000>Error: No data found regarding the collectible \""..FromUTF8(collect).."\" at these coordinates...\nIt's possible that :\n* you have already discovered this collectible;\n* that the coordinates are not exact ;\n* or you are in an instantiated zone</rgb>"));
				else
					self:FocusOnWarband(wb);
				end
			end
			return;
		end
		local x, y, loc = string.find(tempMessage, Filters.playerName..TRAD(" essaye de se localiser autour de (.*)\n$", " tries to locate himself around (.*)\n$"));	
		if(loc~=nil) then
			local x, y, loc = string.find(loc, "(.* .*)$");
			if(loc~=nil) then
				local x=0; local y=0;
				local a, b, y1, y2, dir_y, x1, x2, dir_x = string.find(loc, "(%d*)%.(%d)([NS]), (%d*)%.(%d)([WE])");
				if(x1==nil or x2==nil or dir_x==nil or y1==nil or y2==nil or dir_y==nil) then
					Turbine.Shell.WriteLine("<rgb=#FF5CCD>Impossible de vous reprer sur la carte : vous \195\170tes certainement dans une zone instanci\195\169e.</rgb>");
					return nil;
				end
				x=x1+x2/10;
				y=y1+y2/10;
				if(dir_x~="E") then x=x*(-1); end
				if(dir_y=="N") then y=y*(-1); end
				minimap:UpdatePlayerPosition(x, y);
				self.warbandPane:UpdatePlayerPosition(x, y);
			end
		end
	elseif args.ChatType == Turbine.ChatType.Standard and Filters.playerName~=nil then
		local tempMessage = tostring(args.Message);
		local x, y, loc = string.find(tempMessage, Filters.playerName..TRAD("^Canal (.*) .. HDP.*connexion.*", "^Entered the (.*) - OOC channel"));
		if(loc~=nil) then
			Turbine.Shell.WriteLine("<rgb=#FF5CCD>WIP : entre dans : </rgb>"..loc);
			-- Your connexion with the Chat server has been lost.
		end
	end
end

function WarbandsDialog:AddPromotionCooldown(pts)
	if(pts==nil or type(pts) ~= 'number') then
		return;
	end
	self:AddCooldown(nil, 10003, true, false, nil, pts);
	self:AddCooldown(nil, 10004, true, true, nil, pts);
end

function WarbandsDialog:AddLevelCooldown(level)
	if(level==nil) then
		local p=Turbine.Gameplay.LocalPlayer:GetInstance();
		level=p:GetLevel();
		Filters.class=p:GetClass();
	end
	level = tonumber(level);
	Filters.playerLevel = level;
	self:SaveFilters();	
	
	local pts = 0;
	
	if(level>=7 and level<=105) then
		pts = math.floor((level-5)/2);
	elseif(level>105 and level<=114)then
		pts = 50 + math.floor((level-105)/3);
	elseif(level>114)then
		pts = 53;
	end	
	if(level>=120) then pts = 54; end	
	if(level>=140) then pts = 55; end
	
	if(Filters.class==214) then
		if(level>=15) then pts=pts+1; end
		if(level>=30) then pts=pts+1; end
		if(level>=60) then pts=pts+1; end
		self:AddCooldown(nil, 10020, true, true, pts);
	else
		self:AddCooldown(nil, 10001, true, false, pts);
	end
	self:ApplyFilters();	
end

function WarbandsDialog:AddCooldown(wb, wbName, alwaysOn, verbose, value, progress)
	if(Preferences.debug==true) then local str="NIHIL"; if(wb~=nil) then str=wb.id; end Turbine.Shell.WriteLine("<rgb=#FF5CCD>AddCooldown wb="..str.." wbName=".. (wbName or "nihil")..", value="..(value or "nihil"));  end
	if(Filters.playerName~=nil and string.byte(Filters.playerName, 1)==126) then return; end
	if(wb == nil) then
		wb = GetWarbandByQuestName(wbName);
		if(wb == nil) then
			wb = GetWarbandById(wbName);
		end
		if(wb == nil) then
			local wbName2 = StringCleaner(wbName);
			wb = GetWarbandByQuestName(wbName2);
		end
		if(wb == nil) then
			--Turbine.Shell.WriteLine("<rgb=#FF5CCD>Erreur, aucune troupe de guerre ou Menace itin\195\169rante du nom de "..wbName.." trouv\195\169e. Cette Troupe est donc ignor\195\169e!</rgb>");
			return false;
		end
		--Turbine.Shell.WriteLine(ToUTF8("<rgb=#FF5CCD>".. wb.name .." FOUND</rgb>"));
	end
	local notified = (verbose==nil or verbose==true);
	if(warbandsCooldowns == nil) then
		self:LoadCooldowns();
		notified = false;
	
	end
	for i=1, table.getn(warbandsCooldowns), 1 do
		if(warbandsCooldowns[i][1]==wb.id) then			
			warbandsCooldowns[i][2] = Turbine.Engine.GetDate();
			if(warbandsCooldowns[i][3]==nil) then warbandsCooldowns[i][3]=0; end
			warbandsCooldowns[i][3] = warbandsCooldowns[i][3] + 1;
			warbandsCooldowns[i][4] = alwaysOn;	
			warbandsCooldowns[i].resetTime = self:ComputeResetTime(wb);
			if(wb.inc~=nil and wb.inc.progressMax) then 
				warbandsCooldowns[i].progress=(warbandsCooldowns[i].progress or 0)+progress;
				if(warbandsCooldowns[i].progress<0) then warbandsCooldowns[i].progress=0; end
				if(wb.inc.progressMax~=nil and warbandsCooldowns[i].progress>=wb.inc.progressMax) then
					value = 1;
				else
					value = 0;
				end
			elseif(wb.inc~=nil and value==nil) then
				value = 1;
			end
			warbandsCooldowns[i].value = value;
			self:UpdateNodeStatus(wb.id, warbandsCooldowns[i][2], false, alwaysOn, warbandsCooldowns[i]);
			if(forcesave~=false) then
				self:SaveCooldowns( notified);
			end
			self:UpdateBOF(wb, warbandsCooldowns[i]);
			self:ApplyFilters();
			if(self.warbandPane~=nil and self.warbandPane.wb~=nil and self.warbandPane.wb.id==wb.id) then
				self.warbandPane:SetWarband(wb, warbandsCooldowns[i]);
			end
			return;
		end
	end
	--Turbine.Shell.WriteLine("<rgb=#FF5CCD>DEMANDE DE COOLDOWN: "..wbName.." value="..(value or "nihil"));
	local cd = {wb.id, Turbine.Engine.GetDate(), 1};
	-- if(progress~=nil) then 
		-- if(cd.progress==nil) then cd.progress=0; end
		-- cd.progress=cd.progress+progress;
		-- if(wb.inc.progressMax~=nil and cd.progress>=wb.inc.progressMax) then
			-- value = 1;
		-- end
	-- end	
	if(wb.inc~=nil and wb.inc.progressMax) then 
		cd.progress=progress;
		if(cd.progress<0) then cd.progress=0; end
		if(wb.inc.progressMax~=nil and cd.progress>=wb.inc.progressMax) then
			value = 1;
		else
			value = 0;
		end
	elseif(wb.inc~=nil and value==nil) then
		value = 1;
	end
	cd.value = value;
	cd.resetTime = self:ComputeResetTime(wb);
	table.insert(warbandsCooldowns, cd);
	self:UpdateNodeStatus(wb.id, cd[2], false, alwaysOn, cd);
	if(forcesave~=false) then
		self:SaveCooldowns( notified);
	end
	self:UpdateBOF(wb, cd);
	self:ApplyFilters();
	if(self.warbandPane~=nil and self.warbandPane.wb~=nil and self.warbandPane.wb.id==wb.id) then
		self.warbandPane:SetWarband(wb, cd);
	end
end

function WarbandsDialog:RemoveCooldown(wbId, save)
	if(warbandsCooldowns==nil) then 
		self:LoadCooldowns();
	end
	local found = false;
	for i, cd in ipairs(warbandsCooldowns) do
		if(cd[1]==wbId) then
			table.remove(warbandsCooldowns, i);
			found=true;
			break;
		end
	end
	if(found==true and save==true) then
		self:SaveCooldowns(false);
	end
end

function WarbandsDialog:GetWBTraitCD()
	local listTrait={}; local listCD={};
	local traitPts = 0;
	for i=1, table.getn(warbandsCooldowns), 1 do
		local wb = GetWarbandById(warbandsCooldowns[i][1]);
		if(wb~=nil and wb.enemyType==5) then
			listCD[wb.id]={};
			listCD[wb.id].resetTime = warbandsCooldowns[i].resetTime;
		elseif(wb~=nil and wb.enemyType==4) then
			listTrait[wb.id]={};
			listTrait[wb.id].resetTime = warbandsCooldowns[i].resetTime;
			listTrait[wb.id].value = warbandsCooldowns[i].value;
			listTrait[wb.id].progress = warbandsCooldowns[i].progress;
			traitPts = traitPts + (warbandsCooldowns[i].value or 0);
		end
	end
	listTrait.traitCounts = traitPts;
	return listTrait, listCD, Preferences.custWad;
end

function WarbandsDialog:UpdateBOF(wb, cd, recursive)
	if(Turbine.Chat.commWB_BOF_OnUpdate~=nil) then
		Turbine.Chat.commWB_BOF_OnUpdate();
	end
end

function WarbandsDialog:ComputeResetTime(wb)
	if(wb==nil or (wb.inc~=nil and wb.inc.nocd==true) or wb.enemyType==4) then return nil; end
	local currentGameTime = Turbine.Engine.GetLocalTime();
	local currentDate = Turbine.Engine.GetDate();
	if(Preferences.debug==true) then Turbine.Shell.WriteLine("ComputeResetTime:"..currentGameTime.." wb.repeatable="..(wb.repeatable or "NIHIL")); end
	local resetTime=currentGameTime;
	local resetDay=wb.repeatable;
	if(resetDay==nil or resetDay==8) then resetDay=currentDate.DayOfWeek+1; end
	if(resetDay==9) then 
		if(currentDate.DayOfWeek==1) then 
			resetDay=1;
		elseif(currentDate.DayOfWeek<=5) then 
			resetDay=5; 
		else
			resetDay=1; 
		end
	end
	if(currentDate.DayOfWeek==resetDay) then 
		if(Preferences.utcResetHour<currentDate.Hour) then
			resetTime=resetTime+60*60*24*7;
		end
	elseif(currentDate.DayOfWeek>resetDay) then 
		resetTime=resetTime+60*60*24*(7+resetDay-currentDate.DayOfWeek);
	else
		resetTime=resetTime+60*60*24*(resetDay-currentDate.DayOfWeek);
	end
	resetTime=(Preferences.utcResetHour-currentDate.Hour)*60*60+resetTime;
	resetTime=resetTime-(currentDate.Minute)*60;
	resetTime=resetTime-currentDate.Second;
	if(Preferences.debug==true) then Turbine.Shell.WriteLine("ComputeResetTime=>"..resetTime); end
	return resetTime;
end

function WarbandsDialog:GetWarbandCooldown(wbId)
	for i=1, table.getn(warbandsCooldowns), 1 do
		if(warbandsCooldowns[i][1]==wbId) then
			return warbandsCooldowns[i];
		end
	end
	return nil;
end

function WarbandsDialog:FocusOnWarband(wb)
	if(wb==nil) then
		return;
	end
	if(Filters.tab~=wb.enemyType) then
		self:ShowEnemyTab(wb.enemyType);
	end
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		local node = self.treeView:GetNodes():Get(i):GetWarbandNode(wb);
		if(node~=nil) then
			self.treeView:SetSelectedNode(node);
			return true;
		end
	end	
	return false;
end

function WarbandsDialog:UpdateNodeStatus(wbId, wbLastKill, cdUp, alwaysOn, warbandsCooldown)
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		self.treeView:GetNodes():Get(i):UpdateWBNodeStatus(wbId, wbLastKill, cdUp, alwaysOn, warbandsCooldown);
	end	
end

function WarbandsDialog:SaveFilters(verbose)
	DataSave(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_filters", Filters);
	if(verbose==nil or verbose==true) then
		Turbine.Shell.WriteLine(TRAD("<rgb=#FF5CCD>Warbands and Deeds Slayer: Filtres sauvegard\195\169s</rgb>", "<rgb=#FF5CCD>Warbands and Deeds Slayer: Filters saved</rgb>"));
	end
end

function WarbandsDialog:LoadFilters()
	local tmpFilters = DataLoad(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_filters");
	if(tmpFilters ~= nil) then
		Filters = tmpFilters;	
	end
	if Filters.class==nil or Filters.playerName==nil or Filters.playerLevel==nil then
		local p=Turbine.Gameplay.LocalPlayer:GetInstance();
		if(string.byte(p:GetName(), 1)~=126) then 
			Filters.class=p:GetClass();		
			Filters.playerLevel=p:GetLevel();		
			Filters.playerName=p:GetName();		
			self:AddLevelCooldown(Filters.playerLevel);
		end
	end
	if Filters.levelCalcAlgo==nil then
		Filters.levelCalcAlgo = 3000;
		self:RemoveCooldown(10001, false);
		self:RemoveCooldown(10002, false);
		self:RemoveCooldown(10008, false);
		self:RemoveCooldown(10020, false);
		self:RemoveCooldown(10021, false);
		self:RemoveCooldown(10022, true);
		self:AddLevelCooldown(nil);
	end
end

function SavePOI(verbose)
	DataSave(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_poi", PoiProgress);
	if(verbose==nil or verbose==true) then
		Turbine.Shell.WriteLine(TRAD("<rgb=#FF5CCD>Warbands and Deeds Slayer: Progression sauvegard\195\169s</rgb>", "<rgb=#FF5CCD>Warbands and Deeds Slayer: Progress saved"));
	end
end

function LoadPOI()
	local tmpPOIProgress = DataLoad(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_poi");
	if(tmpPOIProgress ~= nil) then
		PoiProgress = tmpPOIProgress;				
	end
end

function WarbandsDialog:SaveCooldowns(notify)
	DataSave(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_progress", warbandsCooldowns);
	--if(notify==true) then
		self:ReloadCdCounters();
	--end
end

function WarbandsDialog:ReloadCdCounters(doneCount, total)
	if(total == nil) then
		total = GetWarbandsCount(Filters.tab);
	end
	if(doneCount==nil) then
		local cd_count = 0;
		local lastcd = GetLastCdTime();	
		local currentTime = Turbine.Engine.GetLocalTime();		
		for i=1, table.getn(warbandsCooldowns), 1 do
			local wb = GetWarbandById(warbandsCooldowns[i][1]);
			if(wb~=nil) then
				local cd = false;
				if(warbandsCooldowns[i].resetTime~=nil) then
					cd = warbandsCooldowns[i].resetTime>currentTime;
				else
					cd = CompareDate(lastcd, warbandsCooldowns[i][2]);
				end
				local wbType = wb.enemyType or 1;
				if(wbType == Filters.tab and wbType~=3) then
					if(cd and warbandsCooldowns[i][4]~=false) then 
						cd_count=cd_count+(warbandsCooldowns[i].value or 1);
					elseif(wb.repeatable==false or wbType==4) then
						cd_count=cd_count+(warbandsCooldowns[i].value or 1);
					end
				end
			end
		end
		for i, cd in pairs(PoiProgress or {}) do
			local wb = GetWarbandById(i);
			if(wb~=nil and wb.enemyType==Filters.tab) then
				if(wb~=nil and wb.poi~=nil) then
					local cpt = 0;
					for i, poi in pairs(wb.poi) do
						if(cd[poi.id]==true) then cpt=cpt+1; end
					end
					if(cpt>=table.getn(wb.poi)) then cd_count=cd_count+1; end
				elseif(wb~=nil and wb.multipoi~=nil) then
					local cpt = 0; local total=0;
					for i, pois in pairs(wb.multipoi) do
						total=total+table.getn(pois.poi);
						for j, poi in pairs(pois.poi) do
							if(cd[poi.id]==true) then cpt=cpt+1; end
						end
					end
					if(cpt>=total) then cd_count=cd_count+1; end
				end
			end
		end
		self:NotifyUpdate(cd_count, total, false, Filters.tab); 
	else
		self:NotifyUpdate(doneCount, total, true, Filters.tab);
	end
end

function WarbandsDialog:NotifyUpdate(doneCount, total)
end

function WarbandsDialog:LoadCooldowns()
	-- Format {{wb_id, lastkill_Date, killcount},...}
	if(warbandsCooldowns == nil) then
		warbandsCooldowns = DataLoad(Turbine.DataScope.Character, "MortAuxTroupesDeGuerre_progress");
		if(warbandsCooldowns == nil) then
			warbandsCooldowns = {};
		end
	end
	self.lastcd = GetLastCdTime();
	self.nextcd = GetNextCdTime();
	local cd_count = 0;
	for i=1, table.getn(warbandsCooldowns), 1 do
		local cd = CompareDate(self.lastcd, warbandsCooldowns[i][2]);
		self:UpdateNodeStatus(warbandsCooldowns[i][1], warbandsCooldowns[i][2], not cd, warbandsCooldowns[i][4], warbandsCooldowns[i]);
		if(cd or (warbandsCooldowns[i][4]~=nil and warbandsCooldowns[i][4]==true)) then cd_count=cd_count+(warbandsCooldowns.value or 1); end
	end
	self:ReloadCdCounters();
end

function WarbandsDialog:PopupateTreeView()
	rootNodes = self.treeView:GetNodes();	
	rootNodes:Clear();
	
	for i=1, table.getn(wadData), 1 do
		local mapNode = AreaNode(wadData[i].name);
		rootNodes:Add( mapNode );
		if(wadData[i].areas ~= nil) then
			for j=1, table.getn(wadData[i].areas), 1 do
				local area = wadData[i].areas[j];
				local subareaNode = AreaNode(area.name, area.showme~=false);
				if area.showme==false then subareaNode:AlwaysHideMe(); end
				mapNode:GetChildNodes():Add(subareaNode);
				if(area.wads ~= nil) then
					for k=1, table.getn(area.wads), 1 do
						local wad = area.wads[k];
						if Preferences.debug==true or (not (wad.loadingCondition~=nil and ((wad.loadingCondition.class~=nil and ListContainsString(wad.loadingCondition.class,Filters.class)==false) or (wad.loadingCondition.notClass~=nil and ListContainsString(wad.loadingCondition.notClass,Filters.class)==true)))) then
							if(wad.replaceStringsByClass~=nil and Filters.class~=nil) then
								for i,v in ipairs(wad.replaceStringsByClass) do
									if(wad.name~=nil) then wad.name=string.gsub(wad.name, v.key, (v.str[Filters.class] or v.key)); end
									if(wad.how~=nil) then wad.how=string.gsub(wad.how, v.key, (v.str[Filters.class] or v.key)); end
									if(wad.questname~=nil) then wad.questname=string.gsub(wad.how, v.key, (v.str[Filters.class] or v.key)); end
									if(wad.inc~=nil and wad.inc.trigger~=nil) then wad.inc.trigger=string.gsub(wad.inc.trigger, v.key, (v.str[Filters.class] or v.key)); end
									if(wad.check~=nil and wad.check.cdiary~=nil) then wad.check.cdiary=string.gsub(wad.check.cdiary, v.key, (v.str[Filters.class] or v.key)); end
									if(wad.check~=nil and wad.check.qdiary~=nil) then wad.check.qdiary=string.gsub(wad.check.qdiary, v.key, (v.str[Filters.class] or v.key)); end
								end
							end
							if(wad.map==nil) then
								if(area.map~=nil) then wad.map=area.map ;
								else wad.map=wadData[i].map; end
							end
							if(wad.rovingThreatData==nil) then
								if(area.rovingThreatData~=nil) then wad.rovingThreatData=area.rovingThreatData ;
								else wad.rovingThreatData=wadData[i].rovingThreatData; end
							end
							local wadNode = WarbandsNode(wad, wadData[i].region or area.region or wad.region);
							subareaNode:GetChildNodes():Add(wadNode);
						end
					end
				end
			end
		end
	end
end

function WarbandsDialog:ConstructSearchComponents()
	searchLabel = Turbine.UI.Label();
	searchLabel:SetParent( self );
	searchLabel:SetFont(Turbine.UI.Lotro.Font.Verdana12);	
	searchLabel:SetText( TRAD("Recherche :", "Research :"));
	searchLabel:SetForeColor(Turbine.UI.Color( 1, 1, 0.5 ));
	searchLabel:SetPosition( 535, 77 );
	searchLabel:SetSize(100, 30);
	searchLabel:SetMouseVisible( false );	

	local reset = Turbine.UI.Control();
	reset:SetParent( self );
	reset:SetSize(16, 16);
	reset:SetPosition(580+152+4, 74);	
	reset:SetBackground("WalmPlugins/WarbandsSlayer/resources/close.jpg");
	reset.MouseClick = function(sender, args)	
		searchTextArea:SetText("");
		Filters.search = "";
		self:ApplyFilters();
		self:SaveFilters(false);
		reset:SetVisible(false);
	end

	searchTextAreaBorder = Turbine.UI.Label();
	searchTextAreaBorder:SetParent( self );
	searchTextAreaBorder:SetBackColor(Turbine.UI.Color( 1, 1, 0.5 ));
	searchTextAreaBorder:SetPosition( 600, 73 );
	searchTextAreaBorder:SetSize(152, 20);
	searchTextAreaBorder:SetMouseVisible( false );	
	searchTextArea = Turbine.UI.TextBox();
	searchTextArea:SetParent( searchTextAreaBorder );
	searchTextArea:SetText(Filters.search);
	searchTextArea:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft );
	searchTextArea:SetPosition( 1, 1 );
	searchTextArea:SetBackColor(Turbine.UI.Color( 0, 0, 0 ));
	searchTextArea:SetSize(150, 18);
	searchTextArea:SetMultiline(false);
	searchTextArea.TextChanged = function(sender, args)		
		Filters.search = string.lower(searchTextArea:GetText());
		self:ApplyFilters();
		self:SaveFilters(false);
		reset:SetVisible(searchTextArea:GetText()~=nil and string.len(searchTextArea:GetText())>0);
	end	
	reset:SetVisible(searchTextArea:GetText()~=nil and string.len(searchTextArea:GetText())>0);
end

function WarbandsDialog:ApplyFilters()
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		self.treeView:GetNodes():Get(i):AppliFilters(Filters);
	end
end

function WarbandsDialog:ShowAllWarbands()
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		self.treeView:GetNodes():Get(i):ExpandAll();
	end
end

function WarbandsDialog:CollapseAllWarbands()
	for i=1, self.treeView:GetNodes():GetCount(), 1 do
		self.treeView:GetNodes():Get(i):CollapseAll();
	end
end

function WarbandsDialog:GetName()
	return "Warbands";
end

function WarbandsDialog:IsRunning()
	return ( self ~= nil );
end

function WarbandsDialog:OnPOIUpdated(wad, poi)
	if(minimap~=nil) then minimap:OnPOIUpdated(wad, poi);  end
end

function WarbandsDialog:UpdateResponsive()
	self.resizer:SetPosition(self:GetWidth()/2-50, self:GetHeight()-10);
	self.lowerSep:SetPosition( 4, self:GetHeight()-34 );	
	self.optionbtn:SetTop( self:GetHeight()-29 );
	self.createRepetableBtn:SetTop( self:GetHeight()-29 );
	self.treeView:SetHeight(self:GetHeight()-141);
	self.warbandPane:SetHeight2(self:GetHeight()-141);
	self.treeView:GetVerticalScrollBar():SetHeight(self:GetHeight()-141);
end

function WarbandsDialog:Stop()
	self = nil;
end